@@ -14,7 +14,7 @@
 
 package apis
 
-import v1beta1 "github.com/open-cluster-management/multicloud-integrations/pkg/apis/apps/v1beta1"
+import v1beta1 "github.com/stolostron/multicloud-integrations/pkg/apis/apps/v1beta1"
 
 func init() {
 	// Register the types with the Scheme so the components can map objects to GroupVersionKinds and back
