@@ -28,8 +28,8 @@ import (
 	spokeClusterV1 "github.com/open-cluster-management/api/cluster/v1"
 	clusterv1alpha1 "github.com/open-cluster-management/api/cluster/v1alpha1"
 	agentv1 "github.com/open-cluster-management/klusterlet-addon-controller/pkg/apis/agent/v1"
-	gitopsclusterV1beta1 "github.com/open-cluster-management/multicloud-integrations/pkg/apis/apps/v1beta1"
-	"github.com/open-cluster-management/multicloud-integrations/pkg/utils"
+	gitopsclusterV1beta1 "github.com/stolostron/multicloud-integrations/pkg/apis/apps/v1beta1"
+	"github.com/stolostron/multicloud-integrations/pkg/utils"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/klog"
